pub enum SectionAttr {
PureInstructions = 2_147_483_648,
NoToc = 1_073_741_824,
StripStaticSyms = 536_870_912,
LiveSupport = 134_217_728,
Debug = 33_554_432,
SomeInstructions = 1_024,
ExtReloc = 512,
LocReloc = 256,
}Variants
PureInstructions = 2_147_483_648
This section contains only executable machine instructions. The standard tools set this flag for the sections __TEXT,__text, __TEXT,__symbol_stub, and __TEXT,__picsymbol_stub.
NoToc = 1_073_741_824
section contains coalesced symbols that are not to be in a ranlib table of contents
StripStaticSyms = 536_870_912
ok to strip static symbols in this section in files with the MH_DYLDLINK flag
LiveSupport = 134_217_728
blocks are live if they reference live blocks
Debug = 33_554_432
If a segment contains any sections marked with S_ATTR_DEBUG then all sections in that segment must have this attribute. No section other than a section marked with this attribute may reference the contents of this section. A section with this attribute may contain no symbols and must have a section type S_REGULAR. The static linker will not copy section contents from sections with this attribute into its output file. These sections generally contain DWARF debugging info.
SomeInstructions = 1_024
section contains some executable machine instructions.
ExtReloc = 512
section has external relocation entries.
LocReloc = 256
section has local relocation entries.
Implementations